Balladeer — Balladeer 0.39.0

# Balladeer

## API Documentation

- Introduction
- Basics
- Entities
- World
- Map
- Speech
- Drama
- Story
- Scenes
- Themes
- Styles
- Web
- Screenshots
- Change Log

## Overview

Balladeer is a Python package for creating web-enabled interactive screenplay.

For tutorials and updates, please visit the development blog site.

An API manual is included in the code repository and is available to read online.

### Installation

Here are the install instructions for Linux. You need Python version 3.11 or higher.

#### Virtual Environment

1. First make a fresh Python virtual environment:

       python3 -m venv ~/balladeer-app

#### Packages

1. Update the package manager within it:

       ~/balladeer-app/bin/pip install -U pip wheel

2. Install (or update) Balladeer:

       ~/balladeer-app/bin/pip install -U balladeer

### Examples

1. Download the repository as a zip file. Unzip it to a local directory.

2. cd to one of the directories under examples:

       cd balladeer/examples/ex_00_hello_world

3. Run the example like this:

       ~/balladeer-app/bin/python -m main

       Hello, World!